Changelog
=========

1.0.2 (2022-09-05)
------------------

- VideoFileReader source now passes on a file path with the frames as well


1.0.1 (2022-06-13)
------------------

- Fixed error message of DropFrames/SkipSimilarFrames in case data of wrong domain is coming through
- added: filter-frames-by-label-od


1.0.0 (2022-05-05)
------------------

- initial release: from-video-file-od, from-webcam-od, to-video-file-od, drop-frames, skip-similar-frames, calc-frame-changes

